==> haskell-asn1-parse-0.9.5-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-FsIYHCdIOipDvjEOCUDsRz
key:                  asn1-parse-0.9.5-FsIYHCdIOipDvjEOCUDsRz
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  14c55ce8f3696921128597f15ff5fd2f
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-8.10.2/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/asn1-parse-0.9.5
hs-libraries:         HSasn1-parse-0.9.5-FsIYHCdIOipDvjEOCUDsRz
depends:
    asn1-encoding-0.9.6-ErQ0awcTKYWEwLb7ufiUwW
    asn1-types-0.3.4-9LvBvm48t8AG5AvdzCAoqc base-4.14.1.0
    bytestring-0.10.10.0

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.5-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-JNiIxTNtPiz1OqUOihcB3e
key:                  asn1-parse-0.9.5-JNiIxTNtPiz1OqUOihcB3e
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  a59d17a8e7278518542af4c82447afe3
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-8.10.2/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/asn1-parse-0.9.5
hs-libraries:         HSasn1-parse-0.9.5-JNiIxTNtPiz1OqUOihcB3e
depends:
    asn1-encoding-0.9.6-Hb08F38QHccKGf69cOO2QH
    asn1-types-0.3.4-FmVfqvISKVm8kuM3278YSR base-4.14.1.0
    bytestring-0.10.10.0

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
